@@ -43,6 +43,8 @@ class MutableDate(object):
             self._date += timedelta(weeks=amount)
         elif key == 'days':
             self._date += timedelta(days=amount)
+        elif key == 'hours':
+            self._date += timedelta(hours=amount)
         elif key == 'minutes':
             self._date += timedelta(minutes=amount)
         elif key == 'seconds':
@@ -63,6 +65,8 @@ class MutableDate(object):
             self._date -= timedelta(weeks=amount)
         elif key == 'days':
             self._date -= timedelta(days=amount)
+        elif key == 'hours':
+            self._date -= timedelta(hours=amount)
         elif key == 'minutes':
             self._date -= timedelta(minutes=amount)
         elif key == 'seconds':
@@ -86,27 +90,21 @@ class MutableDate(object):
         """Mutate the original moment by changing the year."""
         if number < 0:
             return self.subtract('years', abs(number))
-        date = self._date
-        self._date = datetime(number, date.month, date.day, date.hour, date.minute,
-                              date.second, date.microsecond, date.tzinfo)
+        self._date = self._date.replace(year=number)
         return self
 
     def month(self, number):
         """Mutate the original moment by changing the month."""
         if number < 0:
             return self.subtract('months', abs(number))
-        date = self._date
-        self._date = datetime(date.year, number, date.day, date.hour, date.minute,
-                              date.second, date.microsecond, date.tzinfo)
+        self._date = self._date.replace(month=number)
         return self
 
     def day(self, number):
         """Mutate the original moment by changing the day of the month."""
         if number < 0:
             return self.subtract('days', abs(number))
-        date = self._date
-        self._date = datetime(date.year, date.month, number, date.hour, date.minute,
-                              date.second, date.microsecond, date.tzinfo)
+        self._date = self._date.replace(day=number)
         return self
 
     def weekday(self, number):
@@ -124,36 +122,28 @@ class MutableDate(object):
         """Mutate the original moment by changing the hour."""
         if number < 0:
             return self.subtract('hours', abs(number))
-        date = self._date
-        self._date = datetime(date.year, date.month, date.day, number, date.minute,
-                              date.second, date.microsecond, date.tzinfo)
+        self._date = self._date.replace(hour=number)
         return self
 
     def minutes(self, number):
         """Mutate the original moment by changing the minutes."""
         if number < 0:
             return self.subtract('minutes', abs(number))
-        date = self._date
-        self._date = datetime(date.year, date.month, date.day, date.hour, number,
-                              date.second, date.microsecond, date.tzinfo)
+        self._date = self._date.replace(minute=number)
         return self
 
     def seconds(self, number):
         """Mutate the original moment by changing the seconds."""
         if number < 0:
             return self.subtract('seconds', abs(number))
-        date = self._date
-        self._date = datetime(date.year, date.month, date.day, date.hour, date.minute,
-                              number, date.microsecond, date.tzinfo)
+        self._date = self._date.replace(second=number)
         return self
 
     def microseconds(self, number):
         """Mutate the original moment by changing the seconds."""
         if number < 0:
             return self.subtract('microseconds', abs(number))
-        date = self._date
-        self._date = datetime(date.year, date.month, date.day, date.hour, date.minute,
-                              date.second, number, date.tzinfo)
+        self._date = self._date.replace(microsecond=number)
         return self
 
     def datetime(self):
